@@ -1,17 +1,14 @@
 from __future__ import annotations
 
-import threading
 
 import fire
 
 from python_search.apps.notification_ui import send_notification
 from python_search.entry_capture.entry_inserter_gui.entry_gui_data import GuiEntryData
 from python_search.entry_capture.filesystem_entry_inserter import FilesystemEntryInserter
-from python_search.entry_capture.utils import get_page_title
 from python_search.error.exception import notify_exception
 from python_search.configuration.loader import ConfigurationLoader
 from python_search.environment import is_mac
-from python_search.host_system.windows_focus import Focus
 from python_search.interpreter.interpreter_matcher import InterpreterMatcher
 from python_search.entry_type.type_detector import TypeDetector
 from python_search.entry_type.entity import infer_default_type
@@ -26,6 +23,7 @@ class NewEntryGUI:
     _PREDICT_ENTRY_TYPE_READY = "-predict-entry-type-ready-"
     _ENTRY_NAME_INPUT_SIZE = (17, 7)
     _ENTRY_BODY_INPUT_SIZE = (17, 10)
+    _WINDOW_SIZE = (600, 400)
 
     def __init__(self, configuration=None):
         if configuration:
@@ -40,16 +38,9 @@ class NewEntryGUI:
 
         self.sg = sg
 
-    @staticmethod
-    def focus_or_launch():
-        future = Focus().async_focus_register_new()
-
-        obj = NewEntryGUI()
-        obj.launch_loop(focus_future=future)
-
 
     @notify_exception()
-    def launch_loop(self, default_type=None, default_key="", default_content="", focus_future=None):
+    def launch_loop(self, default_type=None, default_key="", default_content=""):
         """
         Create a new inferred entry based on the clipboard content
         """
@@ -65,7 +56,6 @@ class NewEntryGUI:
             default_content=default_content,
             default_key=default_key,
             default_type=default_type,
-            focus_future=focus_future,
         )
 
     def _save_entry_data(self, entry_data: GuiEntryData):
@@ -89,9 +79,7 @@ class NewEntryGUI:
         window_title: str = "New",
         default_key: str = "",
         default_content: str = "",
-        serialize_output=False,
         default_type="Snippet",
-        focus_future=None,
     ) -> GuiEntryData:
         """
         Launch the entries capture GUI.
@@ -172,21 +160,14 @@ class NewEntryGUI:
             ],
         ]
 
-        if focus_future:
-            print("Waiting for focus")
-            result = focus_future.result()
-            if result:
-                print("Focus succeeded, not starting new window")
-                return
-
         window = self.sg.Window(
             window_title,
             layout,
             font=(self._FONT, font_size),
             finalize=True,
+            size=self._WINDOW_SIZE,
         )
 
-
         window.set_title("Register New")
 
         window[self._TITLE_INPUT].bind("<Escape>", "Escape")
@@ -197,16 +178,6 @@ class NewEntryGUI:
         window[self._BODY_INPUT].bind("<Escape>", "Escape"),
         window["type"].bind("<Escape>", "Escape")
 
-        self._classify_entry_type(default_key, default_content, window)
-
-        if not default_key:
-            if default_content.startswith("http"):
-                self._update_title_with_url_title_thread(default_content, window)
-            else:
-                self._generate_title(default_content, window)
-
-
-
         try:
             while True:
                 event, values = window.read()
@@ -224,7 +195,6 @@ class NewEntryGUI:
                 if event and event == "refresh" or "refresh" in event:
                     new_content = Clipboard().get_content()
                     window[self._BODY_INPUT].update(new_content)
-                    self._generate_title(new_content, window)
                     self._classify_entry_type(default_key, new_content, window)
                     continue
 
@@ -248,7 +218,6 @@ class NewEntryGUI:
 
 
                 if event and (event == "write" or event == "-entry-name-write"):
-
                     selected_tags = []
                     if self._tags:
                         for key, value in values.items():
@@ -274,57 +243,21 @@ class NewEntryGUI:
         except:
             notify_exception()
 
-    def _update_title_with_url_title_thread(self, content: str, window):
-        import PySimpleGUI as sg
-        window: sg.Window = window
-
-        def _update_title(content: str, window):
-            new_title = get_page_title(content)
-            old_title = window[self._TITLE_INPUT]
-            if old_title == new_title:
-                print("Will not upgrade the title as it was already changed")
-                return
-            window[self._TITLE_INPUT].update(new_title)
-
-        threading.Thread(
-            target=_update_title, args=(content, window), daemon=True
-        ).start()
 
     def _sanitize_key(self, key):
         return key.replace("\n", " ").replace(":", " ").strip()
 
-    def _generate_title(self, content, window):
-        from python_search.ps_llm.tasks.entry_title_generator import EntryTitleGenerator
-
-        def _predict_key(window, content):
-            result = None
-            if self._configuration.is_rerank_via_model_enabled():
-                result = EntryTitleGenerator().predict(content)
-
-            if not result:
-                return
-            window.write_event_value(self._PREDICT_ENTRY_TITLE_READY, result)
-
-        threading.Thread(
-            target=_predict_key, args=(window, content), daemon=True
-        ).start()
 
     def _classify_entry_type(self, key_content, content, window):
         if not key_content:
             key_content = ""
 
-        def predict_entry_type(window, content):
-            new_type = self._type_detector.detect(key_content, content)
-            print("new_type", new_type)
+        new_type = self._type_detector.detect(key_content, content)
+        print("new_type", new_type)
 
-            if not new_type:
-                return
-            window.write_event_value(self._PREDICT_ENTRY_TYPE_READY, new_type)
-
-
-        threading.Thread(
-            target=predict_entry_type, args=(window, content), daemon=True
-        ).start()
+        if not new_type:
+            return
+        window.write_event_value(self._PREDICT_ENTRY_TYPE_READY, new_type)
 
     def _checkbox_list(self, tags):
         return ([self.sg.Checkbox(tag, key=tag, default=False) for tag in tags],)
@@ -338,12 +271,11 @@ class NewEntryGUI:
 
 
 def main():
-    fire.Fire(NewEntryGUI().launch_prompt)
+    fire.Fire(NewEntryGUI().launch)
+
+def launch_ui():
+    main()
 
 
 if __name__ == "__main__":
-    fire.Fire(NewEntryGUI().launch)
-
-
-def launch_ui():
-    fire.Fire(NewEntryGUI.focus_or_launch())
+    main()
