@@ -27,10 +27,12 @@ class UrlInterpreter(BaseInterpreter):
         final_cmd = self.cmd
         url = self.cmd["url"]
 
+
         final_cmd["cmd"] = Browser().open_shell_cmd(
-            url, browser=self.cmd.get("browser")
+            url, browser=self.cmd.get("browser"), focus_title=self.cmd.get("app_focus_title")
         )
 
+
         logger.info(f"Final URL command={final_cmd}")
         return CmdInterpreter(final_cmd, self.context).interpret_default()
 
